@@ -6,21 +6,18 @@
 ##' keyStatList(lang = "en", count = 100)
 ##' }
 ##'
-##' @param api_key A string specifying ECOS API key. Need not be specified if
-##'   the key was stored as an environment variable via \code{\link{setKey}} or
-##'   .Renviron.
+## @param api_key A string specifying ECOS API key. Need not be specified if
+##   the key was stored as an environment variable via \code{\link{setKey}} or
+##   .Renviron.
 ##' @param format A string specifying the file format to process - xml, json
 ##' @param lang A string specifying the language of result value - kr (Korean),
 ##'   en (English)
 ##' @param count An integer specifying the number of requests
 ##' @return A data.frame object containing queried information
 ##' @export
-keyStatList <- function(api_key, format = c("xml", "json"), lang = c("kr", "en"),
+keyStatList <- function(format = c("xml", "json"), lang = c("kr", "en"),
                         count = 1000) {
-	if (missing(api_key)) {
-	  ## stop("Please create your api key from website 'https://ecos.bok.or.kr/api/#/AuthKeyApply'")
-    api_key <- .getKey()
-  }
+  api_key <- ecos.getKey()
   format <- match.arg(format)
   lang <- match.arg(lang)
   url <- URLencode(
@@ -30,8 +27,8 @@ keyStatList <- function(api_key, format = c("xml", "json"), lang = c("kr", "en")
   html <- GET(url)
   content <- rawToChar(html$content)
 	if (format == "xml") {
-    .parse_xml(content, type = "keystat")
+    parseXML(content, type = "keystat")
 	} else {
-    .parse_json(content, type = "keystat")
+    parseJSON(content, type = "keystat")
 	}
 }
